Add a set of codecs for kubevirt network with unit test cases

Change-Id: I0734a085258236f524d0d251ab71056eb5602dc4
diff --git a/apps/kubevirt-networking/api/src/main/java/org/onosproject/kubevirtnetworking/api/DefaultKubevirtNetwork.java b/apps/kubevirt-networking/api/src/main/java/org/onosproject/kubevirtnetworking/api/DefaultKubevirtNetwork.java
index dc221ab..97808bb 100644
--- a/apps/kubevirt-networking/api/src/main/java/org/onosproject/kubevirtnetworking/api/DefaultKubevirtNetwork.java
+++ b/apps/kubevirt-networking/api/src/main/java/org/onosproject/kubevirtnetworking/api/DefaultKubevirtNetwork.java
@@ -39,7 +39,7 @@
     private final String segmentId;
     private final IpAddress gatewayIp;
     private final String cidr;
-    private final Set<KubevirtHostRoute> hostRouts;
+    private final Set<KubevirtHostRoute> hostRoutes;
     private final KubevirtIpPool ipPool;
 
     /**
@@ -52,12 +52,12 @@
      * @param segmentId         segment identifier
      * @param gatewayIp         gateway IP address
      * @param cidr              CIDR of network
      * @param hostRouts         a set of host routes
      * @param ipPool            IP pool
      */
     public DefaultKubevirtNetwork(String networkId, Type type, String name,
                                   Integer mtu, String segmentId, IpAddress gatewayIp,
-                                  String cidr, Set<KubevirtHostRoute> hostRouts,
+                                  String cidr, Set<KubevirtHostRoute> hostRoutes,
                                   KubevirtIpPool ipPool) {
         this.networkId = networkId;
         this.type = type;
@@ -66,7 +66,7 @@
         this.segmentId = segmentId;
         this.gatewayIp = gatewayIp;
         this.cidr = cidr;
-        this.hostRouts = hostRouts;
+        this.hostRoutes = hostRoutes;
         this.ipPool = ipPool;
     }
 
@@ -106,8 +106,8 @@
     }
 
     @Override
-    public Set<KubevirtHostRoute> hostRouts() {
-        return ImmutableSet.copyOf(hostRouts);
+    public Set<KubevirtHostRoute> hostRoutes() {
+        return ImmutableSet.copyOf(hostRoutes);
     }
 
     @Override
@@ -127,14 +127,14 @@
         return networkId.equals(that.networkId) && type == that.type &&
                 name.equals(that.name) && mtu.equals(that.mtu) &&
                 gatewayIp.equals(that.gatewayIp) &&
-                cidr.equals(that.cidr) && hostRouts.equals(that.hostRouts) &&
+                cidr.equals(that.cidr) && hostRoutes.equals(that.hostRoutes) &&
                 ipPool.equals(that.ipPool);
     }
 
     @Override
     public int hashCode() {
         return Objects.hash(networkId, type, name, mtu, segmentId, gatewayIp,
-                cidr, hostRouts, ipPool);
+                cidr, hostRoutes, ipPool);
     }
 
     @Override
@@ -147,7 +147,7 @@
                 .add("segmentId", segmentId)
                 .add("gatewayIp", gatewayIp)
                 .add("cidr", cidr)
-                .add("hostRouts", hostRouts)
+                .add("hostRouts", hostRoutes)
                 .add("ipPool", ipPool)
                 .toString();
     }
@@ -52,12 +52,12 @@
      * @param gatewayIp         gateway IP address
      * @param cidr              CIDR of network
-     * @param hostRouts         a set of host routes
+     * @param hostRoutes        a set of host routes
      * @param ipPool            IP pool
      */